@@ -5,6 +5,8 @@ require Mail::Mailer::rfc822;
 
 sub exec {
     my($self, $exe, $args, $to, $sender) = @_;
-    my $address = defined $sender && $sender =~ m/\<(.*?)\> ? $1 : $sender;
+    my $address = defined $sender && $sender =~ m/\<(.*?)\>/ ? $1 : $sender;
+
     exec($exe, (defined $address ? "-f$address" : ()));
+    die "ERROR: cannot run $exe: $!";
 }
